<?php

/**
 * @file
 * Page callbacks for the taxidermy module.
 */

/**
 * Menu callback; displays all nodes associated with a term.
 */
function taxidermy_term_page($term, $depth = 0, $op = 'page') {
  drupal_set_title(check_plain($term->name));

  switch ($op) {
    case 'page':
      // Build breadcrumb based on first hierarchy of first term:
      $breadcrumb = array();
      foreach ($term->parent as $tid) {
        $parent = taxidermy_term_load($tid);
        $breadcrumb[] = l($parent->name, 'taxidermy/term/'. $parent->tid);
      }
      $breadcrumb[] = l(t('Home'), NULL);
      $breadcrumb = array_reverse($breadcrumb);
      drupal_set_breadcrumb($breadcrumb);

      $output = theme('taxidermy_term_page', $term, taxonomy_select_nodes(array($term->tid), 'or', $depth, TRUE));
      drupal_add_feed(url('taxidermy/term/'. $term->tid .'/'. $depth .'/feed'), 'RSS - '. $term->name);
      return $output;
      break;

    case 'feed':
      $channel['link'] = url('taxidermy/term/'. $term->tid .'/'. $depth, array('absolute' => TRUE));
      $channel['title'] = variable_get('site_name', 'Drupal') .' - '. $term->name;
      // HTML will be removed from feed description, so no need to filter here.
      $channel['description'] = $term->description;

      $result = taxonomy_select_nodes(array($term->tid), 'or', $depth, FALSE);
      $items = array();
      while ($row = db_fetch_object($result)) {
        $items[] = $row->nid;
      }

      node_feed($items, $channel);
      break;

    default:
      drupal_not_found();
  }
}

/**
 * Render a taxonomy term page HTML output.
 *
 * @param $tids
 *   An array of term ids.
 * @param $result
 *   A pager_query() result, such as that performed by taxonomy_select_nodes().
 *
 * @ingroup themeable
 */
function theme_taxidermy_term_page($term, $result) {
  drupal_add_css(drupal_get_path('module', 'taxonomy') .'/taxonomy.css');

  $output = '';

  // Check that a description is set.
  if (!empty($term->description)) {
    $output .= '<div class="taxonomy-term-description">';
    $output .= filter_xss_admin($term->description);
    $output .= '</div>';
  }

  $output .= taxonomy_render_nodes($result);

  return $output;
}
